zope.event Documentation — zope.event 4.1.1.dev0 documentation

# `zope.event` Documentation

This package provides a simple event system on which application-specific event systems can be built.

Application code can generate events without being concerned about the event-processing frameworks that might handle the events.

Events are objects that represent something happening in a system. They are used to extend processing by providing processing plug points.

Contents:

- Using `zope.event`
- Theory of Operation
  - Outline
- `zope.event` API Reference
  - Data
  - Functions
- Class-based event handlers
- Hacking on `zope.event`
  - Getting the Code
  - Working in a `virtualenv`
  - Using `zc.buildout`
  - Using `tox`
  - Contributing to `zope.event`

# Indices and tables

- Index
- Module Index
- Search Page